==> mauticGIT-Test-20251111_133203.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/5c/5c46f830a40949ea31d9709d972f5609.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/vibrant/assets/icon_bulb.png */
class __TwigTemplate_8bf129661cf2f1a56a143b4d522979c7 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000@\000\000\000P\000\000\000sE\000\000KiTXtXML:com.adobe.xmp\000\000\000\000\000<?xpacket begin=\"﻿\" id=\"W5M0MpCehiHzreSzNTczkc9d\"?>
<x:xmpmeta xmlns:x=\"adobe:ns:meta/\" x:xmptk=\"Adobe XMP Core 5.6-c138 79.159824, 2016/09/14-01:09:01        \">
 <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">
  <rdf:Description rdf:about=\"\"/>
 </rdf:RDF>
</x:xmpmeta>
<?xpacket end=\"r\"?> I:\000\000IDATxyuϻ}R6[ !,Pj`Y
*J((B4\"VA%qX\\@
D(,\$BKEǹwg34ߜߙr~yn(=v6[`&c`c)~q
IFbK9Oc2Ps6S`?kڨA\000ś\000|O^]bL,VblWbGv\000N/zzkp2C'\000N=^ݰ?fuvmNSU&&ۜ_Fh~m<qGUXcWջ|=/:yy9~U\\E'\thrR77om?8
8
?Mx5Pٛ:RF
]2}rC.x餀Clg)X0J:9w0],/YPa7;UaSN뉥.>w
8:)[Wcâ)`^QP6%+,[KE]ٚUέx>oMkd@YInC)
\\/ǻ4>m)`I<^ӍOcI2_ |*.|Gb\\4.}a\t8
vsiSVT\\VyҚSG,_ vIB[0E_&u.c۲Ήg,^4CVGh+nƽ8ޠ-q`?01
7`^\"|\teHe99yCuqf%)KY6FC7Μ_:F5P% NpIߦu4Z*˅oO
#񒒲WlpCgYRR`?xZ\"vH+&̲<oא- {^)d*`
v2Z_,6h狗p#xAyG
Ň:`37ſLr~\$u(MMp7)P랤ƓWz
}~!yb)}J2^cUZ}beR^27ѺqprYDwI!+Pp_YBaMON?e+d:E=>Otߓ­zɜ
u7ǩ{z孒4
nn|~<1)9VFA<{aakd.hf䊑&ŇDJL?8(, ҡQÒk2)4ܨb:T7ຑoɠ˚b_~ul#,2tmx3{;[߉'d`aR.nphrT,#VU]<HmZaܔ<Xu{8%W?[ì/Be^,p}9H<V
v;9WKNNViˤ}Q{?OʮU-'x5Eǀ4{dlpnRypNo\"w%c_|0+qéb=M<~#/( C62{eG'CjduYԨŸ\$)FsEe
*v\tH#E`G%^Җ/W@mO[-6iΑ=ɆRw<0GsDK!&Sl
/-g91o\$vly@\$T<)>K^l?Ojl3EXE:W,id!U'RSR.c3PL0W+n6Jh^6t̟8-|6w`Cê32\\&*w.b>n\$|\\)znp){X\\9 -Y*@jUlkf#1Q>kD=d\tC8TɔXʭYcPdT\\~~V\tovOԑ:஋eZ]]QPZ-eRMW>RĞq
sjr6,[j{=5^ԭe'Q굩j˧R\$nCMINկ!)ݟ~)L(}<[xhQWiwS-!9n\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/vibrant/assets/icon_bulb.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/vibrant/assets/icon_bulb.png", "/var/www/mautic-ktn/themes/vibrant/assets/icon_bulb.png");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/5c/5c46f830a40949ea31d9709d972f5609.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/vibrant/assets/icon_bulb.png */
class __TwigTemplate_8bf129661cf2f1a56a143b4d522979c7 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000@\000\000\000P\000\000\000sE\000\000KiTXtXML:com.adobe.xmp\000\000\000\000\000<?xpacket begin=\"﻿\" id=\"W5M0MpCehiHzreSzNTczkc9d\"?>
<x:xmpmeta xmlns:x=\"adobe:ns:meta/\" x:xmptk=\"Adobe XMP Core 5.6-c138 79.159824, 2016/09/14-01:09:01        \">
 <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">
  <rdf:Description rdf:about=\"\"/>
 </rdf:RDF>
</x:xmpmeta>
<?xpacket end=\"r\"?> I:\000\000IDATxyuϻ}R6[ !,Pj`Y
*J((B4\"VA%qX\\@
D(,\$BKEǹwg34ߜߙr~yn(=v6[`&c`c)~q
IFbK9Oc2Ps6S`?kڨA\000ś\000|O^]bL,VblWbGv\000N/zzkp2C'\000N=^ݰ?fuvmNSU&&ۜ_Fh~m<qGUXcWջ|=/:yy9~U\\E'\thrR77om?8
8
?Mx5Pٛ:RF
]2}rC.x餀Clg)X0J:9w0],/YPa7;UaSN뉥.>w
8:)[Wcâ)`^QP6%+,[KE]ٚUέx>oMkd@YInC)
\\/ǻ4>m)`I<^ӍOcI2_ |*.|Gb\\4.}a\t8
vsiSVT\\VyҚSG,_ vIB[0E_&u.c۲Ήg,^4CVGh+nƽ8ޠ-q`?01
7`^\"|\teHe99yCuqf%)KY6FC7Μ_:F5P% NpIߦu4Z*˅oO
#񒒲WlpCgYRR`?xZ\"vH+&̲<oא- {^)d*`
v2Z_,6h狗p#xAyG
Ň:`37ſLr~\$u(MMp7)P랤ƓWz
}~!yb)}J2^cUZ}beR^27ѺqprYDwI!+Pp_YBaMON?e+d:E=>Otߓ­zɜ
u7ǩ{z孒4
nn|~<1)9VFA<{aakd.hf䊑&ŇDJL?8(, ҡQÒk2)4ܨb:T7ຑoɠ˚b_~ul#,2tmx3{;[߉'d`aR.nphrT,#VU]<HmZaܔ<Xu{8%W?[ì/Be^,p}9H<V
v;9WKNNViˤ}Q{?OʮU-'x5Eǀ4{dlpnRypNo\"w%c_|0+qéb=M<~#/( C62{eG'CjduYԨŸ\$)FsEe
*v\tH#E`G%^Җ/W@mO[-6iΑ=ɆRw<0GsDK!&Sl
/-g91o\$vly@\$T<)>K^l?Ojl3EXE:W,id!U'RSR.c3PL0W+n6Jh^6t̟8-|6w`Cê32\\&*w.b>n\$|\\)znp){X\\9 -Y*@jUlkf#1Q>kD=d\tC8TɔXʭYcPdT\\~~V\tovOԑ:஋eZ]]QPZ-eRMW>RĞq
sjr6,[j{=5^ԭe'Q굩j˧R\$nCMINկ!)ݟ~)L(}<[xhQWiwS-!9n\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/vibrant/assets/icon_bulb.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/vibrant/assets/icon_bulb.png", "/var/www/html/mauticGIT-Test/themes/vibrant/assets/icon_bulb.png");
    }
}
